Module dot

Module dot 

DOT rendering helpers for lattice comparison graphs.

Structs

LatticeDotData
Input data for rendering a pair of lattices as a Graphviz DOT graph.

Functions

pinyin_lattice_dot
Renders a Chinese pinyin lattice comparison as Graphviz DOT.
romaji_lattice_dot
Renders a Japanese romaji lattice comparison as Graphviz DOT.
symbols_to_string
Converts trace symbols back to a string.