pub struct DistanceWorkspace { /* private fields */ }Expand description
Reusable buffers for repeated lattice distance computations.
The plain convenience functions allocate temporary buffers for each call. Use this workspace when scoring many lattice pairs, such as inside a candidate matrix, to reuse the DP and threshold-search allocations while preserving the same exact results.
Implementations
Sourceimpl DistanceWorkspace
impl DistanceWorkspace
Sourcepub fn try_distance(
&mut self,
left: &Lattice,
right: &Lattice,
) -> Result<usize, DistanceError>
pub fn try_distance( &mut self, left: &Lattice, right: &Lattice, ) -> Result<usize, DistanceError>
Computes lattice edit distance using this workspace.
Sourcepub fn try_distance_with_cutoff(
&mut self,
left: &Lattice,
right: &Lattice,
threshold: usize,
) -> Result<Option<usize>, DistanceError>
pub fn try_distance_with_cutoff( &mut self, left: &Lattice, right: &Lattice, threshold: usize, ) -> Result<Option<usize>, DistanceError>
Computes lattice edit distance up to threshold using this workspace.
Sourcepub fn try_damerau_distance(
&mut self,
left: &Lattice,
right: &Lattice,
) -> Result<usize, DistanceError>
pub fn try_damerau_distance( &mut self, left: &Lattice, right: &Lattice, ) -> Result<usize, DistanceError>
Computes lattice Damerau-Levenshtein distance using this workspace.
Sourcepub fn try_damerau_distance_with_cutoff(
&mut self,
left: &Lattice,
right: &Lattice,
threshold: usize,
) -> Result<Option<usize>, DistanceError>
pub fn try_damerau_distance_with_cutoff( &mut self, left: &Lattice, right: &Lattice, threshold: usize, ) -> Result<Option<usize>, DistanceError>
Computes lattice Damerau-Levenshtein distance up to threshold using
this workspace.